<?xml version="1.0"?>
<sch:schema xmlns:sch="http://www.ascc.net/xml/schematron">

   <sch:phase id="classificationValidation">

      <sch:p>Validate that the document's security classification policy is valid.</sch:p>

       <sch:active pattern="SCP" />

   </sch:phase>

   <sch:phase id="reservedWordValidation">

      <sch:p>Validate that the document doesn't contain any reserved words.</sch:p>

       <sch:active pattern="RWF" />

   </sch:phase>

   <sch:pattern name="Security Classification Policy" id="SCP">

      <sch:p>A Para's classification value cannot be more sensitive 
         than the Document's classification value.</sch:p> 

      <sch:rule context="Para[translate(@classification, 'ABCDEFGHIJKLMNOPQRSTUVWXYZ',
                                                         'abcdefghijklmnopqrstuvwxyz')='top-secret']">

         <sch:assert test="translate(/Document/@classification, 'ABCDEFGHIJKLMNOPQRSTUVWXYZ',
                                                                'abcdefghijklmnopqrstuvwxyz')='top-secret'">
             If there is a Para is labeled "top-secret" then the Document  
             must be labeled top-secret
         </sch:assert>

      </sch:rule>

      <sch:rule context="Para[translate(@classification, 'ABCDEFGHIJKLMNOPQRSTUVWXYZ',
                                                         'abcdefghijklmnopqrstuvwxyz')='secret']">

         <sch:assert test="(translate(/Document/@classification, 'ABCDEFGHIJKLMNOPQRSTUVWXYZ',
                                                                'abcdefghijklmnopqrstuvwxyz')='top-secret') or
                           (translate(/Document/@classification, 'ABCDEFGHIJKLMNOPQRSTUVWXYZ',
                                                                'abcdefghijklmnopqrstuvwxyz')='secret')">
             If there is a Para is labeled "secret" then the Document  
             must be labeled either secret or top-secret
         </sch:assert>

      </sch:rule>

      <sch:rule context="Para[translate(@classification, 'ABCDEFGHIJKLMNOPQRSTUVWXYZ',
                                                         'abcdefghijklmnopqrstuvwxyz')='confidential']">

         <sch:assert test="(translate(/Document/@classification, 'ABCDEFGHIJKLMNOPQRSTUVWXYZ',
                                                                'abcdefghijklmnopqrstuvwxyz')='top-secret') or
                           (translate(/Document/@classification, 'ABCDEFGHIJKLMNOPQRSTUVWXYZ',
                                                                'abcdefghijklmnopqrstuvwxyz')='secret') or 
                           (translate(/Document/@classification, 'ABCDEFGHIJKLMNOPQRSTUVWXYZ',
                                                                'abcdefghijklmnopqrstuvwxyz')='confidential')">
             If there is a Para is labeled "confidential" then the Document  
             must be labeled either confidential, secret or top-secret
         </sch:assert>

      </sch:rule>

   </sch:pattern>

   <sch:pattern name="Reserved Word Filter" id="RWF">

      <sch:p>These reserved words are not allowed anywhere in the
             document: SCRIPT, FUNCTION (case insensitive).</sch:p> 

      <sch:rule context="Document">

         <sch:assert test="count(//node()[contains(translate(., 'ABCDEFGHIJKLMNOPQRSTUVWXYZ',
                                                                'abcdefghijklmnopqrstuvwxyz'),'script')]) = 0
                           and
                           count(//node()[contains(translate(., 'ABCDEFGHIJKLMNOPQRSTUVWXYZ',
                                                                'abcdefghijklmnopqrstuvwxyz'),'function')]) = 0">
             The document must not contain the words SCRIPT or FUNCTION (case insensitive).
         </sch:assert>

      </sch:rule>

   </sch:pattern>

</sch:schema>